# Copyright 2013-2020 Lawrence Livermore National Security, LLC and other
# Spack Project Developers. See the top-level COPYRIGHT file for details.
#
# SPDX-License-Identifier: (Apache-2.0 OR MIT)

from spack import *
import os


class Dawn(MakefilePackage):
    """ Fukui  Renderer   DAWN (Drawer for Academic WritiNgs) 
    is a renderer, which reads 3D geometrical data and visualize them.  
    It is a vectorized 3D PostScript processor with analytical 
    hidden line/surface removal. 
    It aims at precise technical drawing of complex geometries.  
    It performs geometrical hidden line/surface removal and calculates 
    out all visible parts of the 3D data before drawing.  This drawing 
    algorithm realizes device-independent technical high quality of
    vectorized graphics.
    3D Data files should be generated by a modeler or by hands 
    separately.  If you use DAWN as a visualizer of, 
    say, a simulator of physical experiments, 
    the simulator application itself is recognized as a modeler.
    An important feature of DAWN is that
    it has been developed to visualize 3D data generated by
    a high-energy experimental detector simulator "GEANT4" 
    ( http://geant4.web.cern.ch/geant4 , http://geant4.kek.jp ).  

    Note: we set 'gv' as default pdf/ps viewer, assuming this is
          installed on your system.
    """

    # Note: Dawn homepage not available anymore...
    homepage = "https://geant4.kek.jp/~tanaka"
    #url      = "http://geant4.kek.jp/~tanaka/src/dawn_3_91a.tgz"
    url      = "http://10.10.241.24/software/dawn_3_91a.tgz"

    maintainers = ['sly2j']

    version('3_91a', sha256='81d855ead1117681b188242dd0be3a24e005d9bd4063fd2bda9a7a794ebcf5f4')

    depends_on('tcl')
    depends_on('tk')

    ## Patch to ensure wish is called correctly
    patch('exec.patch')
    patch('install.patch')

    def edit(self, spec, prefix):
        makefile = FileFilter("Makefile")
        makefile.filter('CC= .*', 'CC = ' + env['CC'])
        makefile.filter('CXX = .*', 'CXX = ' + env['CXX'])
        makefile.filter('INSTALL_DIR = .*', 'INSTALL_DIR = {}/bin'.format(prefix))
        os.environ['DAWN_PS_PREVIEWER'] = 'gv'
